#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2022-09-26
# File  : metrics/cisco_cellular_lte.py
#
# Cisco Cellular LTE metrics plugin
#
# 2022-11-10: fixed range for RSRP and RSRQ
#             added range for RSSI
#             added scalars for all
# 2022-11-16: added graph for current band
#
from cmk.gui.i18n import _

from cmk.gui.plugins.metrics import (
    metric_info,
    graph_info,
    perfometer_info,
    check_metrics,
)
check_metrics['check_mk-cisco_cellular'] = {
    'cisco_cellular_rsrp': {'auto_graph': False},
    'cisco_cellular_rsrq': {'auto_graph': False},
    'cisco_cellular_rssi': {'auto_graph': False},
    'cisco_cellular_band': {'auto_graph': False},
}

metric_info['cisco_cellular_rsrp'] = {
    'title': _('RSRP'),
    'unit': 'dbm',
    'color': '22/a',
}
metric_info['cisco_cellular_rsrq'] = {
    'title': _('RSRQ'),
    'unit': 'db',
    'color': '32/a',
}
metric_info['cisco_cellular_rssi'] = {
    'title': _('RSSI'),
    'unit': 'dbm',
    # 'unit': 'count',
    'color': '42/a',
}

metric_info['cisco_cellular_band'] = {
    'title': _('Band'),
    'unit': 'count',
    'color': '12/b',
}

graph_info['cisco_cellular.rsrp'] = {
    'title': _('Reference Signal Received Power'),
    'metrics': [
        ('cisco_cellular_rsrp', 'area'),
    ],
    'scalars': [
        ('cisco_cellular_rsrp:crit,-1,*', 'Critical'),
        ('cisco_cellular_rsrp:warn,-1,*', 'Warning'),
    ],
    'range': ('cisco_cellular_rsrp:max,-', 1),
}

graph_info['cisco_cellular.rsrq'] = {
    'title': _('Reference Signal Received Quality'),
    'metrics': [
        ('cisco_cellular_rsrq', 'area'),
    ],
    'scalars': [
        ('cisco_cellular_rsrq:crit,-1,*', 'Critical'),
        ('cisco_cellular_rsrq:warn,-1,*', 'Critical'),
    ],
     'range': ('cisco_cellular_rsrq:max,-', 1),
}

graph_info['cisco_cellular.rssi'] = {
    'title': _('Received Signal Strength Indicator'),
    'metrics': [
        ('cisco_cellular_rssi', 'area'),
    ],
    'scalars': [
        ('cisco_cellular_rssi:crit,-1,*', 'Critical'),
        ('cisco_cellular_rsrq:warn,-1,*', 'Critical'),
    ],
    'range': ('cisco_cellular_rssi:max,-', 1)
}

graph_info['cisco_cellular.band'] = {
    'title': _('Band'),
    'metrics': [
        ('cisco_cellular_band', 'area'),
    ],
    'scalars': [
        ('13#2196F3', 'LTE'),
        ('12#558B2F', 'WCDMA-2100'),
        ('11#689F38', 'WCDMA-1900'),
        ('10#7CB342', 'WCDMA-850'),
        ('9#8BC34A', 'WCDMA-800'),
        ('8#2E7D32', 'GSM-1900'),
        ('7#388E3C', 'GSM-1800'),
        ('6#43A047', 'GSM-900'),
        ('5#4CAF50', 'GSM-850'),
        ('4#F9A825', 'none'),
        ('3#FFA000', 'invalid'),
        ('2#FFB300', 'unknown'),
        ('1#00ACC1', 'UMTS'),
    ],
    'range': (0, 15)
}
